@@ -1,12 +1,15 @@
 package Aw::Client;
 
-use strict;
-use vars qw($VERSION);
 
-$VERSION = '0.2';
+BEGIN
+{
+	use strict;
+	use vars qw($VERSION);
 
-use Aw;
+	$VERSION = '0.3';
 
+	use Aw;
+}
 
 
 sub new
@@ -375,7 +378,7 @@ Enhanced interface for the Aw.xs Client methods.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@RCN.Com|mailto:Yacob@RCN.Com>
+Daniel Yacob Mekonnen,  L<Yacob@wMUsers.Com|mailto:Yacob@wMUsers.Com>
 
 =head1 SEE ALSO
 
